/*
 *	aegis - project change supervisor
 *	Copyright (C) 1997, 2002, 2005 Peter Miller;
 *	All rights reserved.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 * MANIFEST: interface definition for aefind/tree/this.c
 */

#ifndef AEFIND_TREE_THIS_H
#define AEFIND_TREE_THIS_H

#include <main.h>

/**
  * The tree_this_new function is used to create a new {} expression tree
  * node, allocated in dynamic memory.
  *
  * @param arg
  *     Set to -1 for {}, 0 for {-}, or 1 for {+}
  */
struct tree_ty *tree_this_new(int arg = -1);

#endif /* AEFIND_TREE_THIS_H */
